@@ -2,7 +2,7 @@
 #ifndef _GLIBMM_USTRING_H
 #define _GLIBMM_USTRING_H
 
-/* $Id: ustring.h,v 1.12.4.1 2006/02/27 21:29:48 gustin Exp $ */
+/* $Id: ustring.h 369 2007-01-20 10:19:33Z daniel $ */
 
 /* Copyright (C) 2002 The gtkmm Development Team
  *
@@ -269,13 +269,13 @@ public:
   /*! Construct a ustring as a copy of a substring.
    * @param src %Source ustring.
    * @param i Index of first character to copy from.
-   * @param n Number of characters to copy (defaults to copying the remainder).
+   * @param n Number of UTF-8 characters to copy (defaults to copying the remainder).
    */
   ustring(const ustring& src, size_type i, size_type n=npos);
 
   /*! Construct a ustring as a partial copy of a C string.
    * @param src %Source C string encoded as UTF-8.
-   * @param n Number of characters to copy.
+   * @param n Number of UTF-8 characters to copy.
    */
   ustring(const char* src, size_type n);
 
@@ -570,7 +570,7 @@ public:
 //! @{
 
   /*! Returns a new UTF-8 string with all characters characters converted to
-   * their lowercase equivalent, while honoring the current locale.  The
+   * their uppercase equivalent, while honoring the current locale.  The
    * resulting string may change in the number of bytes as well as in the
    * number of characters.  For instance, the German sharp&nbsp;s
    * <tt>&quot;&szlig;&quot;</tt> will be replaced by two characters
@@ -729,7 +729,7 @@ const ustring_Iterator<T> ustring_Iterator<T>::operator++(int)
 template <class T> inline
 ustring_Iterator<T>& ustring_Iterator<T>::operator--()
 {
-  do --pos_; while((*pos_ & '\xC0') == '\x80');
+  do --pos_; while((static_cast<unsigned char>(*pos_) & 0xC0u) == 0x80);
   return *this;
 }
 
